pub struct TimerItem { /* private fields */ }Expand description
Item that the Timer will place inside the Pendulum.
Because type constructors are not available (yet), we have to tell users what type
we will be placing into the Pendulum that they give us. So as to not leak any
inner type information, we export this unconstructable type, for user type inference.